/*  zweic -- a compiler for Zwei
 *
 *  Stephane Micheloud & LAMP
 *
 *  $Id: DefaultVisitor.java 2251 2005-11-19 18:52:43 +0100 (Sat, 19 Nov 2005) michelou $
 */

package zweic;

import zweic.Tree.*;


/**
 * Implements a visitor that resorts to a default case
 * if the particular visitor method was not overridden.
 */
abstract public class DefaultVisitor implements Visitor {
    public void caseBad(Bad tree)             { caseDefault(tree); }

    public void caseProgram(Program tree)     { caseDefault(tree); }
    public void caseClassDef(ClassDef tree)   { caseDefault(tree); }
    public void caseFieldDecl(FieldDecl tree) { caseDefault(tree); }
    public void caseMethodDef(MethodDef tree) { caseDefault(tree); }

    public void caseIntType(IntType tree)     { caseDefault(tree); }
    public void caseNullType(NullType tree)   { caseDefault(tree); }
    public void caseClassType(ClassType tree) { caseDefault(tree); }

    public void caseWhile(While tree)         { caseDefault(tree); }
    public void caseVar(Var tree)             { caseDefault(tree); }
    public void caseSet(Set tree)             { caseDefault(tree); }
    public void caseDo(Do tree)               { caseDefault(tree); }

    public void caseIf(If tree)               { caseDefault(tree); }
    public void caseUnop(Unop tree)           { caseDefault(tree); }
    public void caseBinop(Binop tree)         { caseDefault(tree); }
    public void caseIdent(Ident tree)         { caseDefault(tree); }
    public void caseNullLit(NullLit tree)     { caseDefault(tree); }
    public void caseIntLit(IntLit tree)       { caseDefault(tree); }
    public void caseBlock(Block tree)         { caseDefault(tree); }
    public void caseNew(New tree)             { caseDefault(tree); }
    public void caseSelect(Select tree)       { caseDefault(tree); }
    public void caseCall(Call tree)           { caseDefault(tree); }

    public void casePrintInt(PrintInt tree)   { caseDefault(tree); }
    public void casePrintChar(PrintChar tree) { caseDefault(tree); }
    public void caseReadInt(ReadInt tree)     { caseDefault(tree); }
    public void caseReadChar(ReadChar tree)   { caseDefault(tree); }

    public abstract void caseDefault(Tree tree);
}
