/*  zweic -- a compiler for Zwei
 *
 *  Stephane Micheloud & LAMP
 *
 *  $Id: PrinterTest.java 2146 2005-11-13 17:39:11 +0100 (Sun, 13 Nov 2005) michelou $
 */

package zweic;

import java.io.*;


/**
 * A small test class for the pretty printer of zweic; it reads in a
 * file and prints out the abstract syntax tree. If the program is
 * erroneous, the compiler will print a corresponding error message
 * instead.
 *
 * usage: java zweic.PrinterTest <file.zwei>
 */
public class PrinterTest {
    public static void main(String[] args) {
        if (args.length < 1) {
            System.err.println("usage: java zweic.PrinterTest <file.zwei>");
            System.exit(1);
        }
        try {
            InputStreamReader in = new FileReader(args[0]);
            Tree tree = new Parser(in).parse();
            in.close();
            if (Report.errors > 0)
                System.err.println(Report.errors + " errors found." );
            else {
                PrintWriter out = (args.length < 2)
                    ? new PrintWriter(System.out)
                    : new PrintWriter(new FileWriter(args[1]));
                new Printer(out).print(tree);
                out.close();
            }
            System.exit((Report.errors > 0) ? 1 : 0);
        }
        catch (IOException e) {
            Report.fail(e.getMessage());
        }
    }
}
